aboutsummaryrefslogtreecommitdiffstats
path: root/protocol.h
diff options
context:
space:
mode:
authorTushar Pankaj <tushar.s.pankaj@gmail.com>2018-10-31 20:40:23 -0500
committerTushar Pankaj <tushar.s.pankaj@gmail.com>2018-11-06 20:12:49 -0600
commit50042af6aec61c495c08d1b83f4c63288a30cc90 (patch)
treeabe833424d124d6df800e9c9cbd0d386c15baa7d /protocol.h
parentFirst draft of protocol (diff)
downloadwg-dynamic-50042af6aec61c495c08d1b83f4c63288a30cc90.tar.xz
wg-dynamic-50042af6aec61c495c08d1b83f4c63288a30cc90.zip
Make better var names
Signed-off-by: Tushar Pankaj <tushar.s.pankaj@gmail.com>
Diffstat (limited to 'protocol.h')
-rw-r--r--protocol.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/protocol.h b/protocol.h
index 2edb942..80b2bd3 100644
--- a/protocol.h
+++ b/protocol.h
@@ -9,7 +9,7 @@
#include <stdint.h>
/* possible types of requests the client can make */
-enum wg_client_request = { WG_MINIMAL = 0 };
+enum wg_client_request = { WG_REQUEST_SIMPLE = 0 };
/* client request message */
struct wg_client_message {
@@ -18,8 +18,8 @@ struct wg_client_message {
/* server request message */
struct wg_server_message {
- uint32_t leased_ip; /* dynamic IP leased to client */
- uint32_t leased_ip_cidr; /* CIDR of dynamic IP leased to client */
+ uint32_t leased_ipv4; /* dynamic IPv4 leased to client */
+ uint32_t leased_ipv4_cidr; /* CIDR of dynamic IPv4 leased to client */
uint32_t lease_timeout; /* activity timeout for the IP lease in seconds */
uint32_t route; /* route for client */
uint32_t route_cidr; /* CIDR of route for client */